<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "failurePath.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gfn="http://www.greenhatsoftware.com/Functions.xsl"
	exclude-result-prefixes="gfn">

	<!-- externalisations -->
	<xsl:variable name="failurePath.label">
		<xsl:text>&failurePath.label;</xsl:text>
	</xsl:variable>

	<xsl:template match="failurePath|subscriberFailurePath|mapperFailurePath"
		mode="summary">
		<xsl:apply-templates select="*" mode="summary" />
	</xsl:template>

	<xsl:template match="failurePath|subscriberFailurePath|mapperFailurePath"
		mode="label">
		<xsl:value-of select="$failurePath.label" />
	</xsl:template>

	<xsl:template match="failurePath|subscriberFailurePath|mapperFailurePath">
		<xsl:variable name="failedActionId" select="*[1]/@id" />

		<!-- Apply templates to the failed action. There may also be associated
			actions that are also class as failing and not part of the failure path eg
			the validate action that is added with a subscriber. These associated actions
			will have the same id attribute. -->
		<xsl:apply-templates select="*[@id=$failedActionId]" />

		<!-- Add a header for the failure path -->
		<xsl:call-template name="addActionInfo">
			<xsl:with-param name="name">
				<xsl:call-template name="getFailurePathDisplayType" />
			</xsl:with-param>
			<xsl:with-param name="class" select="'branch'" />
		</xsl:call-template>

		<div class="branch">
			<!-- Apply templates to the actions that were not reported above. These
				will be the failure path actions. -->
			<xsl:apply-templates select="*[not(@id=$failedActionId)]" />
		</div>
	</xsl:template>

	<xsl:template name="getFailurePathDisplayType">
		<xsl:variable name="type"
			select="$FAILURE_PATHS/*[name()=name(current())]" />
		<xsl:choose>
			<xsl:when test="@executionPath">
				<xsl:value-of
					select="$type/displayType[@executionPath=current()/@executionPath]" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$type/displayType[1]" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>