<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "sqlCommand.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<!-- externalisations -->
	<xsl:variable name="sqlCommand.label">
		<xsl:text>&sqlCommand.label;</xsl:text>
	</xsl:variable>
	<xsl:variable name="sqlCommand.receivedData">
		<xsl:text>&sqlCommand.receivedData;</xsl:text>
	</xsl:variable>
	<xsl:variable name="SQL_STATEMENT_OUTPUT">
		<xsl:text>&sqlCommand.sqlStatement;</xsl:text>
	</xsl:variable>
	<xsl:variable name="ACTION_MESSAGE_OUTPUT">
		<xsl:text>&sqlCommand.validationMessage;</xsl:text>
	</xsl:variable>

	<xsl:variable name="SQL_STATEMENT" select="'sqlStatment'" />

	<xsl:variable name="ACTION_MESSAGE" select="'actionMessage'" />

	<xsl:variable name="COLUMNS_TEXT_NAME" select="'columns'" />
	<xsl:variable name="COLUMN_TEXT_NAME" select="'column'" />
	<xsl:variable name="COLUMN_NAME_TEXT_NAME" select="'columnName'" />

	<xsl:variable name="ROWS_TEXT_NAME" select="'rows'" />
	<xsl:variable name="ROW_TEXT_NAME" select="'row'" />
	<xsl:variable name="DATA_TEXT_NAME" select="'data'" />
	<xsl:variable name="VALUE_TEXT_NAME" select="'value'" />

	<xsl:template match="sqlcommand" mode="summary">
		<xsl:call-template name="processSummaryRow" />
	</xsl:template>

	<xsl:template match="sqlcommand" mode="label">
		<xsl:value-of select="$sqlCommand.label" />
	</xsl:template>

	<xsl:template match="sqlcommand">
		<xsl:call-template name="addActionInfo" />
		<table class="faux">
			<xsl:call-template name="reportSQLStatement" />
			<xsl:call-template name="reportCommonInfo" />
			<xsl:call-template name="reportReturnCode" />
		</table>
	</xsl:template>

	<xsl:template name="reportSQLStatement">
		<xsl:call-template name="copyAttribute">
			<xsl:with-param name="attribute" select="$SQL_STATEMENT" />
			<xsl:with-param name="outputAttribute" select="$SQL_STATEMENT_OUTPUT" />
			<xsl:with-param name="formatNewLines" select="'false'" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="reportReturnCode">
		<xsl:call-template name="copyAttribute">
			<xsl:with-param name="attribute" select="$RETURN_CODE" />
			<xsl:with-param name="outputAttribute" select="$RETURN_CODE_OUTPUT" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="reportActionMessages">
		<xsl:if test="count(@*[name()=$ERROR])!=0">
			<tr>
				<xsl:call-template name="reportInfo">
					<xsl:with-param name="name" select="$ERROR_OUTPUT" />
					<xsl:with-param name="value" select="@*[name()=$ERROR]" />
					<xsl:with-param name="tdSpan" select="4" />
				</xsl:call-template>
			</tr>
		</xsl:if>
		<xsl:if
			test="count(*[name()=$ACTION_MESSAGE and not(@containsResultSet)])!=0">
			<xsl:for-each select="*[name()=$ACTION_MESSAGE and not(@containsResultSet)]">
				<tr>
					<xsl:call-template name="reportInfo">
						<xsl:with-param name="name" select="$ACTION_MESSAGE_OUTPUT" />
						<xsl:with-param name="value" select="text()" />
						<xsl:with-param name="tdSpan" select="4" />
					</xsl:call-template>
				</tr>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportResults">
		<xsl:if test="count(*[name()=$ACTION_MESSAGE and @containsResultSet])!=0">
			<div style="margin: 0px 0px 10px 0px;">
				<xsl:value-of select="$sqlCommand.receivedData" />
				<br />
				<table>
					<xsl:for-each select="*[name()=$ACTION_MESSAGE and @containsResultSet]">
						<xsl:call-template name="handleColumns" />
						<xsl:call-template name="handleRows" />
					</xsl:for-each>
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<xsl:template name="handleColumns">
		<tr>
			<xsl:for-each select="*[name()=$COLUMNS_TEXT_NAME]">
				<xsl:for-each select="*[name()=$COLUMN_TEXT_NAME]">
					<xsl:for-each select="*[name()=$COLUMN_NAME_TEXT_NAME]">
						<th>
							<xsl:value-of select="text()" />
						</th>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:for-each>
		</tr>
	</xsl:template>

	<xsl:template name="handleRows">
		<xsl:for-each select="*[name()=$ROWS_TEXT_NAME]">
			<xsl:for-each select="*[name()=$ROW_TEXT_NAME]">
				<tr>
					<xsl:for-each select="*[name()=$DATA_TEXT_NAME]">
						<xsl:for-each select="*[name()=$VALUE_TEXT_NAME]">
							<td>
								<xsl:value-of select="text()" />
							</td>
						</xsl:for-each>
					</xsl:for-each>
				</tr>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
